Index: lib/src/runner/reporter/no_io_compact.dart |
diff --git a/lib/src/runner/reporter/no_io_compact.dart b/lib/src/runner/reporter/no_io_compact.dart |
index 3afef34af80b638f2a0ca25e0570a596df5150dc..8732110054173ad7baf17a39a46b45a563cf22ae 100644 |
--- a/lib/src/runner/reporter/no_io_compact.dart |
+++ b/lib/src/runner/reporter/no_io_compact.dart |
@@ -2,7 +2,7 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE file. |
-library unittest.runner.reporter.no_io_compact; |
+library test.runner.reporter.no_io_compact; |
import 'dart:async'; |
@@ -20,7 +20,7 @@ const _lineLength = 100; |
// TODO(nweiz): Get rid of this when issue 6943 is fixed. |
/// A reporter that doesn't import `dart:io`, even transitively. |
/// |
/// This is used in place of [CompactReporter] by `lib/unittest.dart`, which |
/// can't transitively import `dart:io` but still needs access to a runner so |
/// that test files can be run directly. |
class NoIoCompactReporter { |
@@ -20,7 +20,7 @@ const _lineLength = 100; |
/// A reporter that doesn't import `dart:io`, even transitively. |
/// |
-/// This is used in place of [CompactReporter] by `lib/unittest.dart`, which |
+/// This is used in place of [CompactReporter] by `lib/test.dart`, which |
/// can't transitively import `dart:io` but still needs access to a runner so |
/// that test files can be run directly. |